pub trait NixPath {
// Required methods
fn is_empty(&self) -> bool;
fn len(&self) -> usize;
fn with_nix_path<T, F>(&self, f: F) -> Result<T>
where F: FnOnce(&CStr) -> T;
}Expand description
Common trait used to represent file system paths by many Nix functions.
Required Methods
Sourcefn with_nix_path<T, F>(&self, f: F) -> Result<T>
fn with_nix_path<T, F>(&self, f: F) -> Result<T>
Execute a function with this path as a CStr.
Mostly used internally by Nix.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".